﻿using System.Windows.Controls;
using System.Windows.Input;
using System.Windows.Interactivity;

namespace ScrollViewerOnPivotSample.Interactivity
{
    /// <summary>
    /// スクロールビューワーの左右に非表示領域がある場合、
    /// 操作および慣性が親コントロールに伝達するのを抑制します。
    /// </summary>
    public class ScrollViewerControlManipulation : Behavior<ScrollViewer>
    {
        protected override void OnAttached()
        {
            base.AssociatedObject.ManipulationCompleted += ScrollViewer_ManipulationCompleted;
            base.OnAttached();
        }

        protected override void OnDetaching()
        {
            base.AssociatedObject.ManipulationCompleted -= ScrollViewer_ManipulationCompleted;
            base.OnAttached();
        }

        private void ScrollViewer_ManipulationCompleted(object sender, ManipulationCompletedEventArgs e)
        {
            var scrollViewer = sender as ScrollViewer;
            e.Handled = e.TotalManipulation.Translation.X > 0 ?
                scrollViewer.HorizontalOffset > 0 :
                scrollViewer.HorizontalOffset + scrollViewer.ViewportWidth < scrollViewer.ExtentWidth;
        }
    }
}